@@ -170,9 +170,12 @@ class Collection(object):
 
         If `to_save` already has an ``"_id"`` then an :meth:`update`
         (upsert) operation is performed and any existing document with
-        that ``"_id"`` is overwritten.  Otherwise an ``"_id"`` will be
-        added to `to_save` and an :meth:`insert` operation is
-        performed. Returns the ``"_id"`` of the saved document.
+        that ``"_id"`` is overwritten. Otherwise an :meth:`insert`
+        operation is performed. In this case if `manipulate` is ``True``
+        an ``"_id"`` will be added to `to_save` and this method returns
+        the ``"_id"`` of the saved document. If `manipulate` is ``False``
+        the ``"_id"`` will be added by the server but this method will
+        return ``None``.
 
         Raises :class:`TypeError` if `to_save` is not an instance of
         :class:`dict`. If `safe` is ``True`` then the save will be
@@ -215,13 +218,15 @@ class Collection(object):
                manipulate=True, safe=False, check_keys=True, **kwargs):
         """Insert a document(s) into this collection.
 
-        If `manipulate` is set, the document(s) are manipulated using
+        If `manipulate` is ``True``, the document(s) are manipulated using
         any :class:`~pymongo.son_manipulator.SONManipulator` instances
-        that have been added to this
-        :class:`~pymongo.database.Database`. Returns the ``"_id"`` of
-        the inserted document or a list of ``"_id"`` values of the
-        inserted documents.  If the document(s) does not already
-        contain an ``"_id"`` one will be added.
+        that have been added to this :class:`~pymongo.database.Database`.
+        In this case an ``"_id"`` will be added if the document(s) does
+        not already contain one and the ``"id"`` (or list of ``"_id"``
+        values for more than one document) will be returned.
+        If `manipulate` is ``False`` and the document(s) does not include
+        an ``"_id"`` one will be added by the server. The server
+        does not return the ``"_id"`` it created so ``None`` is returned.
 
         If `safe` is ``True`` then the insert will be checked for
         errors, raising :class:`~pymongo.errors.OperationFailure` if
@@ -928,8 +933,8 @@ class Collection(object):
           - `reduce`: reduce function (as a JavaScript string)
           - `out` (required): output collection name
           - `merge_output` (optional): Merge output into `out`. If the same
-            key exists in both the result set and the existing output collection,
-            the new key will overwrite the existing key
+            key exists in both the result set and the existing output
+            collection, the new key will overwrite the existing key
           - `reduce_output` (optional): If documents exist for a given key
             in the result set and in the existing output collection, then a
             reduce operation (using the specified reduce function) will be
@@ -957,7 +962,8 @@ class Collection(object):
             raise TypeError("'out' must be an instance of basestring")
 
         if merge_output and reduce_output:
-            raise InvalidOperation("Can't do both merge and re-reduce of output.")
+            raise InvalidOperation("Can't do both merge"
+                                   " and re-reduce of output.")
 
         if merge_output:
             out_conf = {"merge": out}
@@ -1051,9 +1057,12 @@ class Collection(object):
             raise ValueError("Can't do both update and remove")
 
         # No need to include empty args
-        if query: kwargs['query'] = query
-        if update: kwargs['update'] = update
-        if upsert: kwargs['upsert'] = upsert
+        if query:
+            kwargs['query'] = query
+        if update:
+            kwargs['update'] = update
+        if upsert:
+            kwargs['upsert'] = upsert
 
         no_obj_error = "No matching object found"
 
@@ -1065,7 +1074,7 @@ class Collection(object):
                 return None
             else:
                 # Should never get here b/c of allowable_errors
-                raise ValueError("Unexpected Error: %s"%out)
+                raise ValueError("Unexpected Error: %s" % (out,))
 
         return out.get('value')
 
