@@ -134,7 +134,6 @@ def _parse_uri(uri, default_port=27017):
         elif raw_options.find("="):
             options = dict([raw_options.split("=")])
 
-
     return (host_list, db, username, password, collection, options)
 
 
@@ -170,7 +169,6 @@ class _Pool(threading.local):
         if not hasattr(self, "sockets"):
             self.sockets = []
 
-
     def socket(self):
         # We use the pid here to avoid issues with fork / multiprocessing.
         # See test.test_connection:TestConnection.test_fork for an example of
@@ -335,7 +333,7 @@ class Connection(object):  # TODO support auth for pooling
 
         # TODO - Support using other options like w and fsync from URI
         self.__options = options
-        # TODO - Support setting the collection from URI as the Java driver does
+        # TODO - Support setting the collection from URI like the Java driver
         self.__collection = collection
 
         self.__cursor_manager = CursorManager(self)
@@ -669,7 +667,7 @@ class Connection(object):  # TODO support auth for pooling
         helpers._check_command_response(error, self.disconnect)
 
         # TODO unify logic with database.error method
-        if error.get("err", 0) is None:
+        if error.get("err") is None:
             return error
         if error["err"] == "not master":
             self.disconnect()
