@@ -150,11 +150,16 @@ class Cursor(object):
         """
         copy = Cursor(self.__collection, self.__spec, self.__fields,
                       self.__skip, self.__limit, self.__timeout,
-                      self.__tailable, self.__snapshot)
+                      self.__snapshot, self.__tailable)
         copy.__ordering = self.__ordering
         copy.__explain = self.__explain
         copy.__hint = self.__hint
         copy.__batch_size = self.__batch_size
+        copy.__max_scan = self.__max_scan
+        copy.__as_class = self.__as_class
+        copy.__must_use_master = self.__must_use_master
+        copy.__is_command = self.__is_command
+        copy.__kwargs = self.__kwargs
         return copy
 
     def __die(self):
